@@ -5,10 +5,13 @@ import getopt
 import os
 import datetime
 import sys
-from baskit import __author__, __email__, __version__
 from random import randint as random
 from server import Server
 
+__version__ = '0.2.1'
+__author__ = 'Steven McGrath'
+__email__ = 'steve@chigeek.com'
+
 class BaskitCLI(cmd.Cmd):
     prompt = 'baskit_ng>'
     server = None
